## To quickly block and unblock a website

### Installation

   pip install site_block

### To block

   block -a <strong>URL</strong>

### To unblock

   block -r <strong>URL</strong>

### List blocked URLs

   block -l
